export default class {
  execute(properties, target, component) {
    const vm = this
    // Allows time for things to get finalized. For example, select.vue needs time to insert values
    // into hidden fields before they get submitted.
    setTimeout(() => {
      vm.submit(target, component)
    }, 10)
  }

  // Execution flows:
  // Button -> Button.onClick() -> Utils.http.execute() -- doesn't save autofill values
  // Button -> Button.onClick() -> form.submit() -- doesn't execute Form.onSubmit(), so cannot call Utils.http.execute() there
  // Submit -> Form.onSubmit() -> Utils.http.execute() -- save autofill values, but cannot have submit action nested in another action
  // TOTRY: Button -> Button.onClick() -> form.clickSubmit() -> submit.click() -> Form.onSubmit() -> Utils.http.execute()
  submit(target, component) {
    const form = target.closest("form")
    // Analogous to Rails' form_with's local
    if (form.dataset.local) {
      form.submit()
    }
    else {
      const url = form.getAttribute("action")
      const formData = new FormData(form)
      const method = form.getAttribute("method")
      if (method.toUpperCase() === 'GET') {
        const data = {
          url: Utils.url.appendParams(url, formData)
        }
        Utils.http.load(data, target, component)
      } else {
        const data = {
          url: url,
          formData: formData,
          formDataEncoded: true
        }
        Utils.http.execute(data, method, component, (response) => Action.execute(response['onResponse'], target, component))
      }
    }
  }
}
