import TypeUtils from "./type"

export default class {
  static htmlUrl(originalUrl) {
    if (TypeUtils.isString(originalUrl)) {
      let url
      if (originalUrl.indexOf('?') > -1) {
         url = originalUrl.replace(/.json\?/, '?')
      } else{
         url = originalUrl.replace(/.json$/, '')
      }
      url = url.replace(/[\&\?]format=json/, '')
      return url
    }
    return ''
  }

  static jsonUrl(originalUrl) {
    if (typeof originalUrl === 'string') {
      let url = originalUrl
      if (originalUrl.indexOf('?') > -1) {
        if (originalUrl.indexOf('.json?') == -1) {
          // url = originalUrl.replace(/\?/, '.json?')
          url = originalUrl + "&format=json"
        }
      } else{
        if (!originalUrl.endsWith('.json')) {
          // url = originalUrl + ".json"
          url = originalUrl + "?format=json"
        }
      }
      return url
    }
    return ''
  }

  static toFormData(params) {
    const formData = new FormData();
    for (const key in params) {
      formData.append(key, params[key]);
    }
    return formData
  }

  static appendParams(url, params) {
    if (params instanceof FormData) {
      const queryString = new URLSearchParams(params).toString()
      if (queryString.length <= 0) {
        return url
      }
      if (url.contains("?")) {
        return url + `&${queryString}`
      } else {
        return url + `?${queryString}`
      }
    } else {
      return this.appendParams(url, this.toFormData(params))
      // throw "Invalid params"
    }
  }

  // static asQueryString(obj) {
  //   if (!TypeUtils.isObject(obj)) {
  //     return ""
  //   }
  //
  //   var str = [];
  //   for (var p in obj) {
  //     if (obj.hasOwnProperty(p)) {
  //       str.push(encodeURIComponent(p) + "=" + encodeURIComponent(obj[p]))
  //     }
  //   }
  //   return str.join("&")
  // }

  static extractFormActionData(originalUrl, local) {
    if (typeof originalUrl === 'string') {
      const substitute = local ? '' : '.json'
      let url
      if (originalUrl.indexOf('?') > -1){
         url = originalUrl.replace(/.json\?.*/, substitute)
      } else{
         url = originalUrl.replace(/.json$/, substitute)
      }
      return { url: url, params: this.decodeURLParams(originalUrl) }
    }
    return {}
  }

  // https://gist.github.com/pirate/9298155edda679510723
  static decodeURLParams(search) {
    const hashes = search.slice(search.indexOf("?") + 1).split("&");
    return hashes.reduce((params, hash) => {
      const split = hash.indexOf("=")

      if (split < 0) {
        return Object.assign(params, {
          [hash]: null
        })
      }

      const key = hash.slice(0, split)
      const val = hash.slice(split + 1)

      return Object.assign(params, { [key]: decodeURIComponent(val) })
    }, {})
  };
}
